*****************************
The sherpa.astro.xspec module
*****************************

.. currentmodule:: sherpa.astro.xspec

.. automodule:: sherpa.astro.xspec

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      XSSSS_ice
      XSTBabs
      XSTBfeo
      XSTBgas
      XSTBgrain
      XSTBpcf
      XSTBrel
      XSTBvarabs
      XSabsori
      XSacisabs
      XSagauss
      XSagnsed
      XSagnslim
      XSapec
      XSbapec
      XSbbody
      XSbbodyrad
      XSbcempow
      XSbcheb6
      XSbcie
      XSbcoolflow
      XSbcph
      XSbequil
      XSbexpcheb6
      XSbexrav
      XSbexriv
      XSbgadem
      XSbgnei
      XSbkn2pow
      XSbknpower
      XSbmc
      XSbnei
      XSbnpshock
      XSbpshock
      XSbremss
      XSbrnei
      XSbsedov
      XSbsnapec
      XSbtapec
      XSbvapec
      XSbvcempow
      XSbvcheb6
      XSbvcie
      XSbvcoolflow
      XSbvcph
      XSbvequil
      XSbvexpcheb6
      XSbvgadem
      XSbvgnei
      XSbvnei
      XSbvnpshock
      XSbvpshock
      XSbvrnei
      XSbvsedov
      XSbvtapec
      XSbvvapec
      XSbvvcie
      XSbvvgadem
      XSbvvgnei
      XSbvvnei
      XSbvvnpshock
      XSbvvpshock
      XSbvvrnei
      XSbvvsedov
      XSbvvtapec
      XSbvvwdem
      XSbvwdem
      XSbwcycl
      XSbwdem
      XSc6mekl
      XSc6pmekl
      XSc6pvmkl
      XSc6vmekl
      XScabs
      XScarbatm
      XScemekl
      XScempow
      XScevmkl
      XScflow
      XScflux
      XScglumin
      XScheb6
      XScie
      XSclumin
      XScompLS
      XScompPS
      XScompST
      XScompTT
      XScompbb
      XScompmag
      XScomptb
      XScompth
      XSconstant
      XScoolflow
      XScpflux
      XScph
      XScplinear
      XScutoffpl
      XScyclabs
      XSdisk
      XSdiskbb
      XSdiskir
      XSdiskline
      XSdiskm
      XSdisko
      XSdiskpbb
      XSdiskpn
      XSdust
      XSedge
      XSeebremss
      XSeplogpar
      XSeqpair
      XSeqtherm
      XSequil
      XSexpabs
      XSexpcheb6
      XSexpdec
      XSexpfac
      XSezdiskbb
      XSfeklor
      XSgabs
      XSgadem
      XSgaussian
      XSgnei
      XSgrad
      XSgrbcomp
      XSgrbjet
      XSgrbm
      XSgsmooth
      XShatm
      XSheilin
      XShighecut
      XShrefl
      XSireflect
      XSismabs
      XSismdust
      XSjet
      XSkdblur
      XSkdblur2
      XSkerrbb
      XSkerrconv
      XSkerrd
      XSkerrdisk
      XSkyconv
      XSkyrline
      XSlaor
      XSlaor2
      XSlog10con
      XSlogconst
      XSlogpar
      XSlorabs
      XSlorentz
      XSlsmooth
      XSlyman
      XSmeka
      XSmekal
      XSmkcflow
      XSnei
      XSnlapec
      XSnotch
      XSnpshock
      XSnsa
      XSnsagrav
      XSnsatmos
      XSnsmax
      XSnsmaxg
      XSnsx
      XSnteea
      XSnthComp
      XSolivineabs
      XSoptxagn
      XSoptxagnf
      XSpartcov
      XSpcfabs
      XSpegpwrlw
      XSpexmon
      XSpexrav
      XSpexriv
      XSphabs
      XSplabs
      XSplcabs
      XSposm
      XSpowerlaw
      XSpshock
      XSpwab
      XSqsosed
      XSraymond
      XSrdblur
      XSredden
      XSredge
      XSreflect
      XSrefsch
      XSrfxconv
      XSrgsext
      XSrgsxsrc
      XSrnei
      XSsedov
      XSsimpl
      XSsirf
      XSslimbh
      XSsmedge
      XSsnapec
      XSspexpcut
      XSspline
      XSsrcut
      XSsresc
      XSssa
      XSsssed
      XSstep
      XSswind1
      XStapec
      XSthcomp
      XSuvred
      XSvagauss
      XSvapec
      XSvarabs
      XSvashift
      XSvbremss
      XSvcempow
      XSvcheb6
      XSvcie
      XSvcoolflow
      XSvcph
      XSvequil
      XSvexpcheb6
      XSvgabs
      XSvgadem
      XSvgaussian
      XSvgnei
      XSvlorabs
      XSvlorentz
      XSvmcflow
      XSvmeka
      XSvmekal
      XSvmshift
      XSvnei
      XSvnpshock
      XSvoigt
      XSvoigtabs
      XSvphabs
      XSvpshock
      XSvraymond
      XSvrnei
      XSvsedov
      XSvtapec
      XSvvapec
      XSvvcie
      XSvvgadem
      XSvvgnei
      XSvvnei
      XSvvnpshock
      XSvvoigt
      XSvvoigtabs
      XSvvpshock
      XSvvrnei
      XSvvsedov
      XSvvtapec
      XSvvwdem
      XSvwdem
      XSwabs
      XSwdem
      XSwndabs
      XSxilconv
      XSxion
      XSxscat
      XSzTBabs
      XSzagauss
      XSzashift
      XSzbabs
      XSzbbody
      XSzbknpower
      XSzbremss
      XSzcutoffpl
      XSzdust
      XSzedge
      XSzfeklor
      XSzgabs
      XSzgauss
      XSzhighect
      XSzigm
      XSzkerrbb
      XSzlogpar
      XSzlorabs
      XSzlorentz
      XSzmshift
      XSzpcfabs
      XSzphabs
      XSzpowerlw
      XSzredden
      XSzsmdust
      XSzvagauss
      XSzvarabs
      XSzvfeabs
      XSzvgabs
      XSzvgaussian
      XSzvlorabs
      XSzvlorentz
      XSzvoigt
      XSzvoigtabs
      XSzvphabs
      XSzvvoigt
      XSzvvoigtabs
      XSzwabs
      XSzwndabs
      XSzxipab
      XSzxipcf

Class Inheritance Diagram
=========================

.. inheritance-diagram:: XSagauss XSagnsed XSagnslim XSapec XSbapec XSbbody XSbbodyrad XSbcempow XSbcheb6 XSbcie XSbcoolflow XSbcph XSbequil XSbexpcheb6 XSbexrav XSbexriv XSbgadem XSbgnei XSbkn2pow XSbknpower XSbmc XSbnei XSbnpshock XSbpshock XSbremss XSbrnei XSbsedov XSbsnapec XSbtapec XSbvapec XSbvcempow XSbvcheb6 XSbvcie XSbvcoolflow XSbvcph XSbvequil XSbvexpcheb6 XSbvgadem XSbvgnei XSbvnei XSbvnpshock XSbvpshock XSbvrnei XSbvsedov XSbvtapec XSbvvapec XSbvvcie XSbvvgadem XSbvvgnei XSbvvnei XSbvvnpshock XSbvvpshock XSbvvrnei XSbvvsedov XSbvvtapec XSbvvwdem XSbvwdem XSbwcycl XSbwdem XSc6mekl XSc6pmekl XSc6pvmkl XSc6vmekl XScarbatm XScemekl XScempow XScevmkl XScflow XScheb6 XScie XScompLS XScompPS XScompST XScompTT XScompbb XScompmag XScomptb XScompth XScoolflow XScph XScplinear XScutoffpl XSdisk XSdiskbb XSdiskir XSdiskline XSdiskm XSdisko XSdiskpbb XSdiskpn XSeebremss XSeplogpar XSeqpair XSeqtherm XSequil XSexpcheb6 XSexpdec XSezdiskbb XSfeklor XSgadem XSgaussian XSgnei XSgrad XSgrbcomp XSgrbjet XSgrbm XShatm XSjet XSkerrbb XSkerrd XSkerrdisk XSkyrline XSlaor XSlaor2 XSlogpar XSlorentz XSmeka XSmekal XSmkcflow XSnei XSnlapec XSnpshock XSnsa XSnsagrav XSnsatmos XSnsmax XSnsmaxg XSnsx XSnteea XSnthComp XSoptxagn XSoptxagnf XSpegpwrlw XSpexmon XSpexrav XSpexriv XSplcabs XSposm XSpowerlaw XSpshock XSqsosed XSraymond XSredge XSrefsch XSrnei XSsedov XSsirf XSslimbh XSsnapec XSsrcut XSsresc XSssa XSsssed XSstep XStapec XSvagauss XSvapec XSvbremss XSvcempow XSvcheb6 XSvcie XSvcoolflow XSvcph XSvequil XSvexpcheb6 XSvgadem XSvgaussian XSvgnei XSvlorentz XSvmcflow XSvmeka XSvmekal XSvnei XSvnpshock XSvoigt XSvpshock XSvraymond XSvrnei XSvsedov XSvtapec XSvvapec XSvvcie XSvvgadem XSvvgnei XSvvnei XSvvnpshock XSvvoigt XSvvpshock XSvvrnei XSvvsedov XSvvtapec XSvvwdem XSvwdem XSwdem XSzagauss XSzbbody XSzbknpower XSzbremss XSzcutoffpl XSzfeklor XSzgauss XSzkerrbb XSzlogpar XSzlorentz XSzpowerlw XSzvagauss XSzvgaussian XSzvlorentz XSzvoigt XSzvvoigt
   :parts: 1

.. inheritance-diagram:: XSSSS_ice XSTBabs XSTBfeo XSTBgas XSTBgrain XSTBpcf XSTBrel XSTBvarabs XSabsori XSacisabs XScabs XSconstant XScyclabs XSdust XSedge XSexpabs XSexpfac XSgabs XSheilin XShighecut XShrefl XSismabs XSismdust XSlog10con XSlogconst XSlorabs XSlyman XSnotch XSolivineabs XSpcfabs XSphabs XSplabs XSpwab XSredden XSsmedge XSspexpcut XSspline XSswind1 XSuvred XSvarabs XSvgabs XSvlorabs XSvoigtabs XSvphabs XSvvoigtabs XSwabs XSwndabs XSxion XSxscat XSzTBabs XSzbabs XSzdust XSzedge XSzgabs XSzhighect XSzigm XSzlorabs XSzpcfabs XSzphabs XSzredden XSzsmdust XSzvarabs XSzvfeabs XSzvgabs XSzvlorabs XSzvoigtabs XSzvphabs XSzvvoigtabs XSzwabs XSzwndabs XSzxipab XSzxipcf
   :parts: 1

.. inheritance-diagram:: XScflux XScglumin XSclumin XScpflux XSgsmooth XSireflect XSkdblur XSkdblur2 XSkerrconv XSkyconv XSlsmooth XSpartcov XSrdblur XSreflect XSrfxconv XSrgsext XSrgsxsrc XSsimpl XSthcomp XSvashift XSvmshift XSxilconv XSzashift XSzmshift
   :parts: 1
